@@ -162,7 +162,7 @@ impl Library {
         let get_type = elem.attr_required("get-type")?;
         let version = self.read_version(parser, ns_id, elem)?;
         let deprecated_version = self.read_deprecated_version(parser, ns_id, elem)?;
-        let is_fundamental = elem.attr("fundamental").map_or(false, |x| x == "1");
+        let is_fundamental = elem.attr("fundamental").is_some_and(|x| x == "1");
         let (ref_fn, unref_fn) = if is_fundamental {
             (
                 elem.attr("ref-func").map(ToOwned::to_owned),
@@ -172,7 +172,8 @@ impl Library {
             (None, None)
         };
 
-        let is_abstract = elem.attr("abstract").map_or(false, |x| x == "1");
+        let is_abstract = elem.attr("abstract").is_some_and(|x| x == "1");
+        let final_type = elem.attr("final").is_some_and(|x| x == "1");
 
         let mut fns = Vec::new();
         let mut signals = Vec::new();
@@ -194,11 +195,13 @@ impl Library {
             "signal" => self
                 .read_signal(parser, ns_id, elem)
                 .map(|s| signals.push(s)),
-            "property" => self.read_property(parser, ns_id, elem).map(|p| {
-                if let Some(p) = p {
-                    properties.push(p);
-                }
-            }),
+            "property" => self
+                .read_property(parser, ns_id, elem, &symbol_prefix)
+                .map(|p| {
+                    if let Some(p) = p {
+                        properties.push(p);
+                    }
+                }),
             "field" => self.read_field(parser, ns_id, elem).map(|f| {
                 fields.push(f);
             }),
@@ -255,7 +258,7 @@ impl Library {
             properties,
             parent,
             implements: impls,
-            final_type: false, // this will be set during postprocessing
+            final_type,
             doc,
             doc_deprecated,
             version,
@@ -594,6 +597,11 @@ impl Library {
                 deprecated_version,
                 doc,
                 doc_deprecated,
+                get_property: None,
+                set_property: None,
+                finish_func: None,
+                async_func: None,
+                sync_func: None,
             })
         } else {
             Err(parser.fail("Missing <return-value> element"))
@@ -698,11 +706,13 @@ impl Library {
             "signal" => self
                 .read_signal(parser, ns_id, elem)
                 .map(|s| signals.push(s)),
-            "property" => self.read_property(parser, ns_id, elem).map(|p| {
-                if let Some(p) = p {
-                    properties.push(p);
-                }
-            }),
+            "property" => self
+                .read_property(parser, ns_id, elem, &symbol_prefix)
+                .map(|p| {
+                    if let Some(p) = p {
+                        properties.push(p);
+                    }
+                }),
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
             "virtual-method" => self
@@ -1017,6 +1027,18 @@ impl Library {
         let is_method = kind == FunctionKind::Method;
         let version = self.read_version(parser, ns_id, elem)?;
         let deprecated_version = self.read_deprecated_version(parser, ns_id, elem)?;
+        let mut gtk_get_property = None;
+        let mut gtk_set_property = None;
+        let finish_func = c_identifier.and_then(|c_identifier| {
+            elem.attr("finish-func").map(|finish_func_name| {
+                format!(
+                    "{}{finish_func_name}",
+                    c_identifier.strip_suffix(&fn_name).unwrap()
+                )
+            })
+        });
+        let async_func = elem.attr("async-func").map(ToString::to_string);
+        let sync_func = elem.attr("sync-func").map(ToString::to_string);
 
         let mut params = Vec::new();
         let mut ret = None;
@@ -1041,9 +1063,28 @@ impl Library {
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
             "doc-version" => parser.ignore_element(),
             "source-position" => parser.ignore_element(),
-            "attribute" => parser.ignore_element(),
+            "attribute" => {
+                if let (Some(name), Some(value)) = (elem.attr("name"), elem.attr("value")) {
+                    match name {
+                        "org.gtk.Method.get_property" => {
+                            gtk_get_property = Some(value.to_string());
+                            Ok(())
+                        }
+                        "org.gtk.Method.set_property" => {
+                            gtk_set_property = Some(value.to_string());
+                            Ok(())
+                        }
+                        _ => parser.ignore_element(),
+                    }
+                } else {
+                    parser.ignore_element()
+                }
+            }
             _ => Err(parser.unexpected_element(elem)),
         })?;
+
+        let get_property = gtk_get_property.or(elem.attr("get-property").map(ToString::to_string));
+        let set_property = gtk_set_property.or(elem.attr("set-property").map(ToString::to_string));
         // The last argument of a callback is ALWAYS user data, so it has to be marked as such
         // in case it's missing.
         if is_callback && params.last().map(|x| x.closure.is_none()).unwrap_or(false) {
@@ -1081,6 +1122,11 @@ impl Library {
                 deprecated_version,
                 doc,
                 doc_deprecated,
+                get_property,
+                set_property,
+                finish_func,
+                async_func,
+                sync_func,
             })
         } else {
             Err(parser.fail_with_position(
@@ -1309,6 +1355,7 @@ impl Library {
         parser: &mut XmlParser<'_>,
         ns_id: u16,
         elem: &Element,
+        symbol_prefix: &str,
     ) -> Result<Option<Property>, String> {
         let prop_name = elem.attr_required("name")?;
         let readable = elem.attr_bool("readable", true);
@@ -1324,6 +1371,8 @@ impl Library {
         let mut typ = None;
         let mut doc = None;
         let mut doc_deprecated = None;
+        let mut gtk_getter = None;
+        let mut gtk_setter = None;
 
         parser.elements(|parser, elem| match elem.name() {
             "type" | "array" => {
@@ -1346,10 +1395,36 @@ impl Library {
             }
             "doc" => parser.text().map(|t| doc = Some(t)),
             "doc-deprecated" => parser.text().map(|t| doc_deprecated = Some(t)),
-            "attribute" => parser.ignore_element(),
+            "attribute" => {
+                if let (Some(name), Some(value)) = (elem.attr("name"), elem.attr("value")) {
+                    match name {
+                        "org.gtk.Property.get" => {
+                            gtk_getter = value
+                                .split(symbol_prefix)
+                                .last()
+                                .and_then(|p| p.strip_prefix('_'))
+                                .map(|p| p.to_string());
+                            Ok(())
+                        }
+                        "org.gtk.Property.set" => {
+                            gtk_setter = value
+                                .split(symbol_prefix)
+                                .last()
+                                .and_then(|p| p.strip_prefix('_'))
+                                .map(|p| p.to_string());
+                            Ok(())
+                        }
+                        _ => parser.ignore_element(),
+                    }
+                } else {
+                    parser.ignore_element()
+                }
+            }
             _ => Err(parser.unexpected_element(elem)),
         })?;
 
+        let getter = gtk_getter.or(elem.attr("getter").map(ToString::to_string));
+        let setter = gtk_setter.or(elem.attr("setter").map(ToString::to_string));
         if has_empty_type_tag {
             return Ok(None);
         }
@@ -1368,6 +1443,8 @@ impl Library {
                 deprecated_version,
                 doc,
                 doc_deprecated,
+                getter,
+                setter,
             }))
         } else {
             Err(parser.fail_with_position(
